scxpand.data\_util.data\_format
===============================

.. automodule:: scxpand.data_util.data_format

   
   .. rubric:: Functions

   .. autosummary::
   
      load_data_format
   
   .. rubric:: Classes

   .. autosummary::
   
      DataFormat
   